@@ -1,5 +1,5 @@
 def quicktext():
-    reutnr 'Hello, welcome to QuickSample package.'
+    return 'Hello, welcome to QuickSample package.'
 
 
 def anotherfunction():
